import React from "react";
import {useColumn} from "../Column";

/**
 * Column filter definition.
 */
export interface ColumnFilter<T = any, FilterState = any>
{
	/**
	 * Visual element for the filter.
	 */
	element: React.ReactElement;

	/**
	 * Data filter function.
	 * @param data Data to filter
	 * @param filterState Current filter state.
	 * @returns True when data should be kept, false otherwise.
	 */
	filter: (data: T, filterState: FilterState) => boolean;
}

/**
 * Hook to get current column filter state.
 */
export function useFilterState<T = any>(initialValue: T): [T, (newFilterState: T) => void]
{
	// Get current column data.
	const column = useColumn();
	// Return filter state array from current column data.
	return [column.filterState ?? initialValue, column.setFilterState];
}
